embassy-nrf

Crates

git

Versions

nrf54l15-app-s

Flavors

Lines

Enum Lines 

pub enum Lines {
    Single,
    Dual1_1_2,
    Dual1_2_2,
    Quad1_1_4,
    Quad1_4_4,
}
Multi-line SPI mode for the address and data phases.

Maps to CTRLR0.SPI_FRF (data-line width) and SPICTRLR0.TRANSTYPE (whether the address is sent on the command line or the data lines). The command opcode is always sent on a single line.

Variants



Single

Single line (1-1-1): standard MOSI/MISO.



Dual1_1_2

Dual output (1-1-2): single command, single address, dual data.



Dual1_2_2

Dual I/O (1-2-2): single command, dual address, dual data.



Quad1_1_4

Quad output (1-1-4): single command, single address, quad data.



Quad1_4_4

Quad I/O (1-4-4): single command, quad address, quad data.